@@ -1,7 +1,18 @@
 import asyncio
+from typing import AsyncIterator, Iterator, TypeVar
 
 
-def handle_asyncgen(ait):
+def get_or_create_async_loop():
+    try:
+        return asyncio.get_running_loop()
+    except RuntimeError:
+        return asyncio.new_event_loop()
+
+
+I = TypeVar("I")
+
+
+def async_generator_to_generator(ait: AsyncIterator[I]) -> Iterator[I]:
     ait = ait.__aiter__()
 
     async def get_next():
@@ -11,13 +22,9 @@ def handle_asyncgen(ait):
         except StopAsyncIteration:
             return True, None
 
-    try:
-        loop = asyncio.new_event_loop()
-    except RuntimeError:
-        loop = asyncio.get_running_loop()
-
+    loop = get_or_create_async_loop()
     while True:
         done, obj = loop.run_until_complete(get_next())
         if done:
             break
-        yield obj
\ No newline at end of file
+        yield obj
